@@ -2,7 +2,6 @@ import importlib
 
 import pandas as pd
 import numpy as np
-from PyQt5.QtQml import kwargs
 from sklearn.compose import ColumnTransformer
 from sklearn.preprocessing import RobustScaler
 from sklearn.base import BaseEstimator, TransformerMixin
@@ -446,7 +445,7 @@ def pre_process(X, y=None, date_cols: list=None, int_cols: list=None, float_cols
             clean_df = clean_df.dropna()
             # do not reset index here
             # clean_df.reset_index(drop=True, inplace=True)
-            LOGGER.debug('Rows with missing data = {}', len(df) - len(clean_df))
+            LOGGER.debug('Preprocessing, rows with missing data = {}', len(df) - len(clean_df))
             if target_sr is not None:
                 clean_target_sr = clean_target_sr[~null_rows]
                 # do not reset index here
@@ -505,7 +504,8 @@ def pre_process(X, y=None, date_cols: list=None, int_cols: list=None, float_cols
     try:
         if gen_target is not None:
             tmp_X = new_X.copy(deep=True)
-            tmp_X[:, new_y.name] = new_y
+            if new_y is not None:
+                tmp_X[:, new_y.name] = new_y
             target_col = gen_target.get('target_col')
             target_gen_func = gen_target.get('target_gen_func')
             new_y = tmp_X.apply(target_gen_func, axis=1)
@@ -513,6 +513,7 @@ def pre_process(X, y=None, date_cols: list=None, int_cols: list=None, float_cols
                 new_X[target_col] = new_y.copy(deep=True)
             del tmp_X
     except:
+        LOGGER.warning('Something went wrong with target variable generation, skipping ...')
         pass
     if correlated_cols is not None or not (not correlated_cols):
         new_X.drop(columns=correlated_cols, inplace=True)
